import{t as n,b as s,et as d}from"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e831c6eb-90df-40be-ab11-df9dd853a5c7",e._sentryDebugIdIdentifier="sentry-dbid-e831c6eb-90df-40be-ab11-df9dd853a5c7")}catch{}})();const o={},r={class:"organization-settings"};function a(e,t){return s(),d("div",r,"Organization settings")}const f=n(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.5fa6dfbc.js.map
