import{d as R,ez as h,ey as D,r as F,F as x,a as O,b as u,et as E,u as s,c as j,ev as w,f as p,w as f,bo as A,bF as M,cu as $}from"./outputWidgets.4b203988.js";import{e as B,u as S,K as T,F as U}from"./icons.b5300508.js";import{a as V}from"./asyncComputed.e3f401af.js";import"./router.b5e476b6.js";import"./jwt-decode.esm.74bd4619.js";import"./index.7a3abf72.js";import{P as g}from"./project.bf6c1ad8.js";import{O as L}from"./organization.2698a41b.js";import{C as G}from"./CrudView.54167740.js";import{a as J}from"./ant-design.af81433d.js";import{A as K}from"./FormItem.dacf5a0e.js";import{M as q}from"./Modal.96464eb7.js";import"./storage.e938f042.js";import"./index.08241909.js";import"./index.cf4c23b9.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";import"./Title.aa160519.js";import"./Text.574763d2.js";import"./Form.ed264728.js";import"./hasIn.c2d80060.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.0a96fdb4.js";import"./url.fcdccb50.js";import"./index.50465e1e.js";import"./index.fc0a25db.js";(function(){try{var l=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(l._sentryDebugIds=l._sentryDebugIds||{},l._sentryDebugIds[c]="3d67b8c9-26e5-4b96-a25b-469d66f5fd43",l._sentryDebugIdIdentifier="sentry-dbid-3d67b8c9-26e5-4b96-a25b-469d66f5fd43")}catch{}})();const we=R({__name:"Projects",setup(l){const c=[{key:"name",label:"Project Name"}],m=h().params.organizationId,k=D(),{loading:C,result:r,refetch:y}=V(()=>Promise.all([g.list(m),L.get(m)]).then(([t,e])=>({projects:t,organization:e}))),d=({key:t})=>k.push({name:"project",params:{projectId:t}}),P=async t=>{const e=await g.create({organizationId:m,name:t.name});d({key:e.id})},I=async({key:t})=>{var o,a;if(await J("Are you sure you want to delete this project?"))try{await((a=(o=r.value)==null?void 0:o.projects.find(i=>i.id===t))==null?void 0:a.delete())}catch(i){$.error({message:"Error deleting project",description:String(i)})}finally{await y()}},_=async({key:t})=>{var o;const e=(o=r.value)==null?void 0:o.projects.find(a=>a.id===t);if(e){const a=await e.duplicate();d({key:a.id})}},n=F({state:"idle"});function N(t){n.value={state:"renaming",projectId:t.id,newName:t.name}}async function b(t){if(n.value.state==="renaming"&&t){const{projectId:e,newName:o}=n.value;await g.rename(e,o),y()}n.value={state:"idle"}}const z=x(()=>{var t,e;return{columns:[{name:"Project Name",align:"left"},{name:"",align:"right"}],rows:(e=(t=r.value)==null?void 0:t.projects.map(o=>{var a,i;return{key:o.id,cells:[{type:"link",text:o.name,to:`/projects/${encodeURIComponent(o.id)}`},{type:"actions",actions:[{icon:B,label:"Go to project",onClick:d},{icon:S,label:"Rename project",onClick:()=>N(o)},...(i=(a=r.value)==null?void 0:a.organization)!=null&&i.featureFlags.DUPLICATE_PROJECTS?[{icon:T,label:"Duplicate",onClick:_}]:[],{icon:U,label:"Delete",onClick:I,dangerous:!0}]}]}}))!=null?e:[]}});return(t,e)=>{const o=O("ant-form");return u(),E(A,null,[s(r)?(u(),j(G,{key:0,"entity-name":"project",loading:s(C),title:`${s(r).organization.name}'s Projects`,description:"Organize your team's work into different Projects, each with it's own subdomain.","create-button-text":"Create Project","empty-title":"No projects here yet",table:z.value,fields:c,onCreate:P},null,8,["loading","title","table"])):w("",!0),p(s(q),{open:n.value.state==="renaming",title:"Rename organization",onCancel:e[1]||(e[1]=a=>b(!1)),onOk:e[2]||(e[2]=a=>b(!0))},{default:f(()=>[n.value.state==="renaming"?(u(),j(o,{key:0,layout:"vertical"},{default:f(()=>[p(s(K),{label:"New name"},{default:f(()=>[p(s(M),{value:n.value.newName,"onUpdate:value":e[0]||(e[0]=a=>n.value.newName=a)},null,8,["value"])]),_:1})]),_:1})):w("",!0)]),_:1},8,["open"])],64)}}});export{we as default};
//# sourceMappingURL=Projects.e9451b62.js.map
