import{F as t}from"./Form.ed264728.js";import{aJ as d,cj as n}from"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0ec706d9-c999-40bb-9ddb-59461b2b67f6",e._sentryDebugIdIdentifier="sentry-dbid-0ec706d9-c999-40bb-9ddb-59461b2b67f6")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.b192920a.js.map
