import{S as p}from"./Sidebar.0fa43f18.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.d9750609.js";import{G as d,H as b,I as f}from"./icons.b5300508.js";import{d as l,ez as u,F as g,a as _,b as y,c as v,w as r,f as a}from"./outputWidgets.4b203988.js";import{a as z}from"./asyncComputed.e3f401af.js";import"./router.b5e476b6.js";import"./jwt-decode.esm.74bd4619.js";import"./index.7a3abf72.js";import{O as w}from"./organization.2698a41b.js";import{B as I}from"./BaseLayout.89faeb15.js";import"./index.50465e1e.js";import"./logo.084e5d7c.js";import"./Text.574763d2.js";import"./index.4ded4700.js";import"./FormItem.dacf5a0e.js";import"./hasIn.c2d80060.js";import"./storage.e938f042.js";import"./index.08241909.js";import"./index.cf4c23b9.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e98ef4b8-b905-4059-92f3-6b2e1dfe7ffb",e._sentryDebugIdIdentifier="sentry-dbid-e98ef4b8-b905-4059-92f3-6b2e1dfe7ffb")}catch{}})();const K=l({__name:"Organization",setup(e){const n=u().params.organizationId,{result:t}=z(()=>w.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:b,path:"members"},{name:"Billing",icon:f,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:r(()=>[a(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:r(()=>[a(p,{class:"sidebar",sections:s})]),content:r(()=>[a(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.f22f9873.js.map
