import{a as e,A as t,B as i}from"./Text.574763d2.js";import{A as o}from"./Link.daf6c82a.js";import{a as d,A as r}from"./Title.aa160519.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="c9b9cb90-ba79-4f6a-95dd-d65ed2558d43",n._sentryDebugIdIdentifier="sentry-dbid-c9b9cb90-ba79-4f6a-95dd-d65ed2558d43")}catch{}})();e.Text=t;e.Title=d;e.Paragraph=r;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,d),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.689acef2.js.map
