.pop-over[data-v-fb19726b]{visibility:hidden;user-select:none;z-index:5000;position:fixed;min-width:240px;max-width:510px;background-color:#fcfcfc;border-radius:11px;border:1px solid #d5d5d5;box-shadow:0 0 15px #00000029;overflow:hidden}.header[data-v-fb19726b]{display:flex;flex-direction:row;align-items:center;justify-content:space-between;padding:.7rem 1.05rem .7rem 2.1rem;border-bottom:1px solid #d5d5d5;cursor:grab}.header-content[data-v-fb19726b]{display:inline;line-height:1;color:#535353;font-weight:500}.body[data-v-fb19726b]{overflow:auto}.body .body-content[data-v-fb19726b]{display:flex;flex-direction:column}.icon[data-v-fb19726b]{align-self:flex-end;cursor:pointer;width:24px;height:24px;min-height:24px;margin:10px 10px 0 0}.hu-color-picker{padding:10px;background:#1d2024;border-radius:4px;box-shadow:0 0 16px #00000029;z-index:1}.hu-color-picker.light{background:#f7f8f9}.hu-color-picker.light .color-show .sucker{background:#eceef0}.hu-color-picker.light .color-type .name{background:#e7e8e9}.hu-color-picker.light .color-type .value{color:#666;background:#eceef0}.hu-color-picker.light .colors.history{border-top:1px solid #eee}.hu-color-picker canvas{vertical-align:top}.hu-color-picker .color-set{display:flex}.hu-color-picker .color-show{margin-top:8px;display:flex}.saturation{position:relative;cursor:pointer}.saturation .slide{position:absolute;left:100px;top:0;width:10px;height:10px;border-radius:50%;border:1px solid #fff;box-shadow:0 0 1px 1px #0000004d;pointer-events:none}.color-alpha{position:relative;margin-left:8px;cursor:pointer}.color-alpha .slide{position:absolute;left:0;top:100px;width:100%;height:4px;background:#fff;box-shadow:0 0 1px #0000004d;pointer-events:none}.sucker{width:30px;fill:#9099a4;background:#2e333a;cursor:pointer;transition:all .3s}.sucker.active,.sucker:hover{fill:#1593ff}.hue{position:relative;margin-left:8px;cursor:pointer}.hue .slide{position:absolute;left:0;top:100px;width:100%;height:4px;background:#fff;box-shadow:0 0 1px #0000004d;pointer-events:none}.colors{padding:0;margin:0}.colors.history{margin-top:10px;border-top:1px solid #2e333a}.colors .item{position:relative;width:16px;height:16px;margin:10px 0 0 10px;border-radius:3px;box-sizing:border-box;vertical-align:top;display:inline-block;transition:all .1s;cursor:pointer}.colors .item:nth-child(8n+1){margin-left:0}.colors .item:hover{transform:scale(1.4)}.colors .item .alpha{height:100%;border-radius:4px}.colors .item .color{position:absolute;left:0;top:0;width:100%;height:100%;border-radius:3px}.color-type{display:flex;margin-top:8px;font-size:12px}.color-type .name{width:60px;height:30px;float:left;display:flex;justify-content:center;align-items:center;color:#999;background:#252930}.color-type .value{flex:1;height:30px;min-width:100px;padding:0 12px;border:0;color:#fff;background:#2e333a;box-sizing:border-box}.color-picker-wrapper[data-v-fd80ee1f]{display:flex;align-items:center;justify-content:center}.color-input-container[data-v-fd80ee1f]{min-width:2em;height:2em;border-radius:.5rem;cursor:pointer;border:1px solid #eaeaea}.color-input-container.selected[data-v-fd80ee1f]{border:1px solid green}.color-input-container .colorpicker[data-v-fd80ee1f]{opacity:0;width:100%;height:100%}
