import"./outputWidgets.4b203988.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="908bd754-8499-481e-92cb-81d2ebf44da0",r._sentryDebugIdIdentifier="sentry-dbid-908bd754-8499-481e-92cb-81d2ebf44da0")}catch{}})();class s{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=s.get(e);return s.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{s as S};
//# sourceMappingURL=storage.e938f042.js.map
