import{N as f}from"./NavbarControls.b5354b08.js";import{d as _,ey as b,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as a,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.4b203988.js";import{A as C}from"./Text.574763d2.js";import{T as I,A as o}from"./TabPane.763603c5.js";import{c as A}from"./index.4ded4700.js";import"./asyncComputed.e3f401af.js";import"./index.85e6facd.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.0a96fdb4.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.3aeb8cf8.js";import"./ant-design.af81433d.js";import"./index.fc0a25db.js";import"./Modal.96464eb7.js";import"./storage.e938f042.js";import"./Link.daf6c82a.js";import"./index.689acef2.js";import"./Title.aa160519.js";import"./index.571ba84c.js";import"./workspaces.12ceebcb.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";import"./url.fcdccb50.js";import"./popupNotifcation.6d467042.js";import"./CircularLoading.31bc2494.js";import"./icons.b5300508.js";import"./index.70306866.js";import"./hasIn.c2d80060.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="72b2442c-8de9-46f8-ad04-09559fa74d66",r._sentryDebugIdIdentifier="sentry-dbid-72b2442c-8de9-46f8-ad04-09559fa74d66")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(r){const t=b(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(f,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:l})=>[(c(),x(T(l)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.73cb59ad.js.map
