import{Q as n,f,N as c,e7 as g,a9 as u}from"./outputWidgets.4b203988.js";import{B as i,b as y}from"./Text.574763d2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="018eb270-d9af-4ff5-b0c0-2745ffffc427",e._sentryDebugIdIdentifier="sentry-dbid-018eb270-d9af-4ff5-b0c0-2745ffffc427")}catch{}})();const h=()=>c(y(),["component"]),s=(e,o)=>{let{slots:a,attrs:t}=o;const r=n(n(n({},e),{component:"div"}),t);return f(i,r,a)};s.displayName="ATypographyParagraph";s.inheritAttrs=!1;s.props=h();const w=s;var m=globalThis&&globalThis.__rest||function(e,o){var a={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(a[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(a[t[r]]=e[t[r]]);return a};const P=g(1,2,3,4,5),T=()=>n(n({},c(y(),["component","strong"])),{level:Number}),p=(e,o)=>{let{slots:a,attrs:t}=o;const{level:r=1}=e,d=m(e,["level"]);let l;P.includes(r)?l=`h${r}`:(u(),l="h1");const b=n(n(n({},d),{component:l}),t);return f(i,b,a)};p.displayName="ATypographyTitle";p.inheritAttrs=!1;p.props=T();const O=p;export{w as A,O as a};
//# sourceMappingURL=Title.aa160519.js.map
