import{d as b,ez as f,ey as C,F as g,b as _,c as I,u as h}from"./outputWidgets.4b203988.js";import{b as w}from"./index.7a3abf72.js";import"./router.b5e476b6.js";import"./jwt-decode.esm.74bd4619.js";import{C as i}from"./connector.5eff825e.js";import{a as k}from"./asyncComputed.e3f401af.js";import{u as x,o as E}from"./icons.b5300508.js";import{C as D}from"./CrudView.54167740.js";import"./index.cf4c23b9.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";import"./FormItem.dacf5a0e.js";import"./hasIn.c2d80060.js";import"./storage.e938f042.js";import"./index.08241909.js";import"./Title.aa160519.js";import"./Text.574763d2.js";import"./Form.ed264728.js";import"./Modal.96464eb7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.0a96fdb4.js";import"./url.fcdccb50.js";import"./index.50465e1e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7bc185a5-8423-4d6b-9306-3fe095bac185",o._sentryDebugIdIdentifier="sentry-dbid-7bc185a5-8423-4d6b-9306-3fe095bac185")}catch{}})();const U=b({__name:"Connectors",setup(o){const r=f(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(w.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:m,result:l,refetch:d}=k(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=l.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:x,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:E,label:"Delete",dangerous:!0,async onClick(){await n.delete(),d()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),I(D,{"entity-name":"connector",loading:h(m),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{U as default};
//# sourceMappingURL=Connectors.9ee8995e.js.map
