import"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="30dddefb-daf3-4ac0-a597-3e0eeb76ff48",e._sentryDebugIdIdentifier="sentry-dbid-30dddefb-daf3-4ac0-a597-3e0eeb76ff48")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.fcdccb50.js.map
