import{d,ez as g,F as l,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.4b203988.js";import{B as _}from"./BaseLayout.89faeb15.js";import{a as h}from"./asyncComputed.e3f401af.js";import"./router.b5e476b6.js";import"./jwt-decode.esm.74bd4619.js";import"./index.7a3abf72.js";import{P as z}from"./project.bf6c1ad8.js";import{O as y}from"./organization.2698a41b.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.d9750609.js";import{S as I}from"./Sidebar.0fa43f18.js";import{e as w,L as O,M as C,N as P,O as k,P as B,q as L,Q as $,s as M,G as N,H as S,I as x}from"./icons.b5300508.js";import"./FormItem.dacf5a0e.js";import"./hasIn.c2d80060.js";import"./storage.e938f042.js";import"./index.08241909.js";import"./index.cf4c23b9.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";import"./logo.084e5d7c.js";import"./Text.574763d2.js";import"./index.4ded4700.js";import"./index.50465e1e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="78f635a1-c680-42e6-983c-a20ee459484f",o._sentryDebugIdIdentifier="sentry-dbid-78f635a1-c680-42e6-983c-a20ee459484f")}catch{}})();const na=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:P},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:B},{name:"Files",path:"files",icon:L},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:N,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:S,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:x,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{na as default};
//# sourceMappingURL=Project.d28f5c12.js.map
