import"./outputWidgets.4b203988.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="e27f19e1-85d7-4eb4-87da-4f71fd8d6b12",x._sentryDebugIdIdentifier="sentry-dbid-e27f19e1-85d7-4eb4-87da-4f71fd8d6b12")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.2f7b47ed.js.map
