import{Q as s}from"./outputWidgets.4b203988.js";import{c as i,d}from"./index.30bcda71.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="40db5616-de93-4c27-a901-66be3a5c822a",e._sentryDebugIdIdentifier="sentry-dbid-40db5616-de93-4c27-a901-66be3a5c822a")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:a,RangePicker:o}=i(d),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:o,TimePicker:f,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.2f55b9b3.js.map
