import{z as t}from"./index.cf4c23b9.js";import{w as s}from"./metadata.e7b504f9.js";import"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="847b5d90-35c1-40d7-bc92-404ae7d0bbc8",e._sentryDebugIdIdentifier="sentry-dbid-847b5d90-35c1-40d7-bc92-404ae7d0bbc8")}catch{}})();const a=s.stages.flatMap(e=>e.transitions.flatMap(n=>n.typeName)),r=t.object({type:t.enum(["forms","hooks","jobs","scripts","conditions","iterators"]),id:t.string(),title:t.string(),position:t.object({x:t.number(),y:t.number()}),props:t.object({path:t.string().nullable(),filename:t.string().nullable(),variableName:t.string().nullable()})}),o=t.object({id:t.string(),type:t.enum(a),sourceStageId:t.string(),targetStageId:t.string(),props:t.object({conditionValue:t.string().nullable()})}),l=t.object({stages:t.array(r),transitions:t.array(o)});export{l as s};
//# sourceMappingURL=schema.98f691b2.js.map
