import"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="87176255-8fe5-4bc5-bd2e-37ed817264b5",e._sentryDebugIdIdentifier="sentry-dbid-87176255-8fe5-4bc5-bd2e-37ed817264b5")}catch{}})();function d(e,n,o=!1,a=!0){const r=(a?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=o?r:r.replace(/_+/g,"_");return n?c:c.replace(/_$/,"")}function l(e){var r;const o=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),a=/[a-z0-9]+/g,t=o.match(a);return(r=t==null?void 0:t.join("-"))!=null?r:""}export{l as a,d as n};
//# sourceMappingURL=string.ebbe001f.js.map
