var o=Object.defineProperty;var i=(t,e,a)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:a}):t[e]=a;var n=(t,e,a)=>(i(t,typeof e!="symbol"?e+"":e,a),a);import{g as c,h as d,_ as f}from"./outputWidgets.4b203988.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d3fdd133-2082-40a7-9350-dc2854a0e70d",t._sentryDebugIdIdentifier="sentry-dbid-d3fdd133-2082-40a7-9350-dc2854a0e70d")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>f(()=>import("./Player.42e9a5dd.js"),["assets/Player.42e9a5dd.js","assets/FormRunner.fdadd483.js","assets/outputWidgets.4b203988.js","assets/outputWidgets.3c848cd5.css","assets/url.fcdccb50.js","assets/storage.e938f042.js","assets/pubsub.3a2fa885.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.b5300508.js","assets/CircularLoading.31bc2494.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.7db6fd7e.js","assets/PlayerNavbar.d1d85d81.css","assets/ActionButton.fee7ae20.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.c31e5796.js","assets/WidgetsFrame.97ae601d.css","assets/index.a717dae8.js","assets/Card.789851ad.js","assets/TabPane.763603c5.js","assets/hasIn.c2d80060.js","assets/index.689acef2.js","assets/Text.574763d2.js","assets/Link.daf6c82a.js","assets/Title.aa160519.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.2f7b47ed.js","assets/asyncComputed.e3f401af.js","assets/Player.6fed9080.css"])}],g=c({history:d("/"),routes:u,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await r.init(e)}const s=class{constructor(e){this.config=e}static async init(e){s.instance=new s(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let r=s;n(r,"instance",null);export{r as S,g as a,u as r,w as s};
//# sourceMappingURL=index.85e6facd.js.map
