import{d as m,ez as c,u as e,b as p,c as u,et as y,f as o,w as a,be as _,ao as d,ev as g,e as b,eB as x}from"./outputWidgets.4b203988.js";import"./router.b5e476b6.js";import"./jwt-decode.esm.74bd4619.js";import"./index.7a3abf72.js";import{O as w}from"./organization.2698a41b.js";import{a as h}from"./asyncComputed.e3f401af.js";import{a as k}from"./Title.aa160519.js";import{A as B}from"./index.70306866.js";import{A}from"./index.6c62aa95.js";import{A as C}from"./Text.574763d2.js";import{C as I}from"./Card.789851ad.js";import"./FormItem.dacf5a0e.js";import"./hasIn.c2d80060.js";import"./storage.e938f042.js";import"./index.08241909.js";import"./index.cf4c23b9.js";import"./record.3809e80c.js";import"./pubsub.3a2fa885.js";import"./TabPane.763603c5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="9092ce72-16b2-47d9-9742-344239737f90",t._sentryDebugIdIdentifier="sentry-dbid-9092ce72-16b2-47d9-9742-344239737f90")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=h(()=>w.get(n));return(D,T)=>e(l)?(p(),u(e(_),{key:0})):(p(),y("div",v,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(k),{level:3},{default:a(()=>[d("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(A),{style:{"margin-top":"0"}}),o(e(I),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[d("Plan")]),_:1}),b("div",z,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.728da548.js.map
