import"./outputWidgets.4b203988.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="ac4f4360-87f1-46de-b7fa-1ffbfcbdd4ee",e._sentryDebugIdIdentifier="sentry-dbid-ac4f4360-87f1-46de-b7fa-1ffbfcbdd4ee")}catch{}})();function n(e,d){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...d})}export{n as g};
//# sourceMappingURL=datetime.e1df2409.js.map
